ziggy.hdmc.frame

Package ziggy :: Package hdmc :: Module frame |
[hide private]
[frames] | no frames]

# Source Code for Module ziggy.hdmc.frame

     1  #! /usr/bin/env python
     2
     3  import sys, os, subprocess, shlex, random
     4
     5 -def main():
     6          os.system('chmod a+rwx numpy_random_means.py')
     7          for i in range(0):
     8                  p = subprocess.Popen(['./numpy_random_means.py'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     9                  output, error = p.communicate()
    10                  sts = p.wait()
    11                  print output
    12
    13
    14  if __name__ == "__main__":
    15          main()
    16